# InvoiceScheduleStatus

The status of the invoice schedule. 

## Enum

* `PENDING` (value: `'Pending'`)

* `PARTIALLYPROCESSED` (value: `'PartiallyProcessed'`)

* `PAUSED` (value: `'Paused'`)

* `FULLYPROCESSED` (value: `'FullyProcessed'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


